#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const yargs = require("yargs");
const beautify = require("js-beautify");
const path = require("path");
const fs = require("fs");
const mkdirp = require("mkdirp");
const argv = yargs(process.argv.slice(2))
    .scriptName("gabble")
    .usage("$0 -s <source_dir> -o <output_dir> [options]")
    .options({
    s: {
        type: "string",
        describe: "The source directory. Should contain the pages.",
        demandOption: true,
    },
    x: {
        type: "array",
        describe: "Directory names to exclude. For example, 'components'. This prevents all directories named 'components' inside the pages directory from being treated as pages.",
    },
    o: {
        type: "string",
        describe: "The output directory.",
        demandOption: true,
    },
    init: {
        type: "string",
        describe: "Require this file before compiling pages. This could be used to initialize the environment.",
    },
    noext: {
        type: "boolean",
        describe: "Do not use html extension for files.",
        default: false,
    },
    tabsize: {
        type: "number",
        describe: "Indentation for HTML formatting. Defaults to 2.",
        default: 2,
    },
    ignoreerrors: {
        type: "boolean",
        describe: "Ignore compilation errors and move to the next page.",
        default: false,
    },
})
    .parseSync();
const sourceDir = path.resolve(argv.s);
const outputDir = path.resolve(argv.o);
const excludedPaths = (((_a = argv.x) === null || _a === void 0 ? void 0 : _a.map((x) => x.toString())) || []).map((excludedPath) => excludedPath.startsWith("/") ? excludedPath : `/${excludedPath}`);
const requireFile = argv.init ? path.resolve(argv.init) : undefined;
function getFiles(dir) {
    const files = [];
    const entries = fs.readdirSync(dir, {
        withFileTypes: true,
    });
    for (const entry of entries) {
        const fullPath = path.join(dir, entry.name);
        const excluded = excludedPaths.some((excludedPath) => fullPath.endsWith(excludedPath));
        if (entry.isDirectory()) {
            if (!excluded) {
                files.push(...getFiles(path.join(dir, entry.name)));
            }
        }
        else {
            if (!excluded) {
                files.push(path.join(dir, entry.name));
            }
        }
    }
    return files;
}
function writeFile(fullPath, contents) {
    const outputDir = path.dirname(fullPath);
    const filename = path.basename(fullPath);
    const filenameWithoutExt = filename.replace(".html", "");
    const { finalDir, finalFilename } = argv.noext && filename !== "index.html"
        ? {
            finalDir: path.resolve(outputDir, filenameWithoutExt),
            finalFilename: "index.html",
        }
        : { finalDir: outputDir, finalFilename: filename };
    if (!fs.existsSync(finalDir)) {
        mkdirp.sync(finalDir);
    }
    const formatted = beautify.html(contents, { indent_size: argv.tabsize });
    fs.writeFileSync(path.resolve(finalDir, finalFilename), formatted);
}
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        const files = getFiles(sourceDir).filter((x) => x.endsWith(".js"));
        if (requireFile) {
            require(requireFile);
        }
        for (const file of files) {
            try {
                const relativePath = file.replace(sourceDir + "/", "");
                const pageGeneratorOpts = {
                    filePath: file,
                    relativePath,
                };
                const page = require(file).default;
                const pageResult = yield page(pageGeneratorOpts);
                if (Array.isArray(pageResult)) {
                    for (const result of pageResult) {
                        const newPath = path.resolve(outputDir, (result.path || relativePath).replace(/\.js$/, ".html"));
                        writeFile(newPath, result.html);
                    }
                }
                else {
                    const newPath = path.resolve(outputDir, (pageResult.path || relativePath).replace(/\.js$/, ".html"));
                    writeFile(newPath, pageResult.html);
                }
            }
            catch (ex) {
                console.log(ex.toString());
                console.log(`Skipped ${file}.`);
            }
        }
    });
}
run();
//# sourceMappingURL=index.js.map